@@ -12,7 +12,7 @@
 /* |                                                                   | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: PaintEvent.c,v 1.2 1996/04/15 14:21:49 torsten Exp $ */
+/* $Id: PaintEvent.c,v 1.3 1997/07/12 17:56:03 torsten Exp $ */
 
 #include <X11/IntrinsicP.h>
 #include "PaintP.h"
@@ -112,7 +112,7 @@ opHandleEvent(Widget w, XtPointer dataArg, XEvent * event, Boolean * junk)
 	switch (event->type) {
 	case ButtonPress:
 	case ButtonRelease:
-#ifdef TRUNC_SNAP
+#if 1
 	    event->xbutton.x = event->xbutton.x -
 		(event->xbutton.x % snap);
 	    event->xbutton.y = event->xbutton.y -
@@ -133,7 +133,7 @@ opHandleEvent(Widget w, XtPointer dataArg, XEvent * event, Boolean * junk)
 		return;
 	    break;
 	case MotionNotify:
-#ifdef TRUNC_SNAP
+#if 1
 	    event->xmotion.x = event->xmotion.x -
 		(event->xmotion.x % snap);
 	    event->xmotion.y = event->xmotion.y -
