@@ -13,7 +13,7 @@
 /* |                                                                   | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: brushOp.c,v 1.14 1997/05/31 08:16:47 torsten Exp $ */
+/* $Id: brushOp.c,v 1.18 1998/04/16 19:38:10 torsten Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -58,7 +58,8 @@
 
 #define BRUSH(name) (char **) CONCAT(name, _xpm)
 
-#define BLEND(a, b, x)	((x)*(b) + (1.0-(x))*(a))
+/* this blend function ensures to reach the final color - ACZ: */
+#define BLEND(a, b, x)	((x)*(b) + (1.0039-(x))*(a))
 
 typedef struct {
     Pixmap pixmap;
@@ -111,6 +112,7 @@ typedef struct {
     BrushType brushtype;
     Pixmap pixmap;
     int width, height;
+    int lastX, lastY;
     Palette *brushPalette;
 } LocalInfo;
 
@@ -183,14 +185,53 @@ press(Widget w, LocalInfo * l, XButtonEvent * event, OpInfo * info)
     UndoStart(w, info);
 
     draw(w, info, l, event->x, event->y);
+    if (info->surface == opPixmap) {
+	l->lastX = event->x;
+	l->lastY = event->y;
+    }
 }
 
 static void 
 motion(Widget w, LocalInfo * l, XMotionEvent * event, OpInfo * info)
 {
+    int x = l->lastX;
+    int y = l->lastY;
+    int d, dx, dy, x_incrE, y_incrE = 0, x_incrNE, y_incrNE, incrE, incrNE;
+    
     if (!event->state || ((info->surface == opWindow) && info->isFat))
 	return;
-    draw(w, info, l, event->x, event->y);
+    x_incrE = x_incrNE = x < event->x ? 1 : (x == event->x ? 0 : -1);
+    y_incrNE = y < event->y ? 1 : (y == event->y ? 0 : -1);
+    dx = abs(event->x - x);
+    dy = abs(event->y - y);
+    if (dy > dx) {
+	int t = dx;
+	dx = dy;
+	dy = t;
+	x_incrE = 0;
+	y_incrE = y_incrNE;
+    }
+    d = dy * 2 - dx;
+    incrE = dy*2;
+    incrNE = (dy - dx) * 2;
+    do {
+	if (d <= 0) {
+	    d += incrE;
+	    x += x_incrE;
+	    y += y_incrE;
+	}
+	else {
+	    d += incrNE;
+	    x += x_incrNE;
+	    y += y_incrNE;
+	}
+	draw(w, info, l, x, y);
+    }
+    while (x != event->x || y != event->y);
+    if (info->surface == opPixmap) {
+	l->lastX = event->x;
+	l->lastY = event->y;
+    }
 }
 
 static void 
@@ -702,10 +743,12 @@ createDialog(Widget w)
     Pixmap pix;
     int nw, nh, ox, oy;
     XpmAttributes xpmAttr;
-
-    shell = XtVaCreatePopupShell("brush",
+    Arg args[3];
+    int nargs = 0;
+    
+    shell = XtVisCreatePopupShell("brush",
 				 topLevelShellWidgetClass, w,
-				 NULL);
+				 args, nargs);
 
     form = XtVaCreateManagedWidget(NULL,
 				   formWidgetClass, shell,
