@@ -14,7 +14,7 @@
 /* |                                                                   | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: chroma.c,v 1.7 1998/04/16 19:40:27 torsten Exp $ */
+/* $Id: chroma.c,v 1.8 2000/09/02 08:26:20 torsten Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -22,6 +22,9 @@
 #include <X11/Xaw/Form.h>
 #include <X11/Xaw/AsciiText.h>
 #include <X11/Xaw/Toggle.h>
+#undef NeedFunctionPrototypes
+#define NeedFunctionPrototypes 1
+#undef NeedWidePrototypes
 #include <X11/Xaw/Scrollbar.h>
 #include <X11/Xaw/Command.h>
 #include <X11/Shell.h>
