@@ -13,13 +13,16 @@
 /* |								       | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: color.c,v 1.11 1997/09/03 19:31:07 torsten Exp $ */
+/* $Id: color.c,v 1.12 2000/09/02 08:26:20 torsten Exp $ */
 
 #include <stdio.h>
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
 #include <X11/Xaw/Form.h>
 #include <X11/Xaw/Label.h>
+#undef NeedFunctionPrototypes
+#define NeedFunctionPrototypes 1
+#undef NeedWidePrototypes
 #include <X11/Xaw/Scrollbar.h>
 #include <X11/Xaw/AsciiText.h>
 #include <X11/Xaw/Command.h>
