@@ -13,7 +13,7 @@
 /* |								       | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: cutCopyPaste.c,v 1.11 1997/05/07 05:53:50 torsten Exp $ */
+/* $Id: cutCopyPaste.c,v 1.13 2000/09/02 21:46:11 torsten Exp $ */
 
 #include <X11/StringDefs.h>
 #include <X11/Intrinsic.h>
@@ -184,7 +184,7 @@ stdPasteCB(Widget paint, XtPointer infoArg, Atom * selection, Atom * type,
 	    }
 	}
 	/*
-	**  Are there more possible selections comming?
+	**  Are there more possible selections coming?
 	 */
 	if (info->count != 0)
 	    return;
@@ -281,9 +281,8 @@ stdPasteCB(Widget paint, XtPointer infoArg, Atom * selection, Atom * type,
 		  0, 0, rect.width, rect.height, 0, 0);
 	XtReleaseGC(paint, gc);
 
-	PwRegionSet(paint, &rect, pix, newMask);
+        PwRegionSet(paint, &rect, pix, newMask);
     }
-
     setToSelectOp();
 }
 
@@ -311,6 +310,13 @@ StdPasteCallback(Widget w, XtPointer paintArg, XtPointer junk)
     }
 }
 
+void 
+StdSnapshotCallback(Widget w, XtPointer paintArg, XtPointer junk)
+{
+    Widget paint = (Widget) paintArg;
+    SnapshotImage(GetShell(w), paintArg, 1);
+}
+
 void 
 StdClearCallback(Widget w, XtPointer paintArg, XtPointer junk2)
 {
@@ -403,9 +409,20 @@ StdRedoCallback(Widget w, XtPointer paintArg, XtPointer junk2)
 	PwRegionSet((Widget) pw, &pw->paint.region.rect, None, None);
 }
 
+void 
+StdRefreshCallback(Widget w, XtPointer paintArg, XtPointer junk2)
+{
+    PaintWidget pw = (PaintWidget) paintArg;
+
+    XtUnmapWidget((Widget) pw);
+    XtMapWidget((Widget) pw);
+}
+
 void 
 ClipboardSetImage(Widget w, Image * image)
 {
+    if (image==NULL) return;
+
     if (Global.region.pix != None)
 	XFreePixmap(XtDisplay(w), Global.region.pix);
     if (Global.region.mask != None)
@@ -677,6 +694,12 @@ ccpAddRedo(Widget w, Widget paint)
     XtAddCallback(w, XtNcallback, StdRedoCallback, (XtPointer) paint);
 }
 
+void 
+ccpAddRefresh(Widget w, Widget paint)
+{
+    XtAddCallback(w, XtNcallback, StdRefreshCallback, (XtPointer) paint);
+}
+
 void 
 ccpAddCut(Widget w, Widget paint)
 {
@@ -697,6 +720,14 @@ ccpAddPaste(Widget w, Widget paint)
 		  (XtCallbackProc) StdPasteCallback, (XtPointer) paint);
 }
 
+void 
+ccpAddSnapshot(Widget w, Widget paint)
+{
+    XtVaSetValues(w, XtNsensitive, True, NULL);
+    XtAddCallback(w, XtNcallback,
+		  (XtCallbackProc) StdSnapshotCallback, (XtPointer) paint);
+}
+
 void 
 ccpAddClear(Widget w, Widget paint)
 {
@@ -707,6 +738,7 @@ void
 ccpAddDuplicate(Widget w, Widget paint)
 {
     addFunction(w, paint, (XtCallbackProc) StdDuplicateCallback);
+
 }
 
 /*
@@ -718,25 +750,37 @@ ccpAddSaveRegion(Widget w, Widget paint)
     addFunction(w, paint, (XtCallbackProc) StdSaveRegionFile);
 }
 
+void 
+ccpAddCloneRegion(Widget w, Widget paint)
+{
+    addFunction(w, paint, (XtCallbackProc) StdCloneRegionFile);
+}
+
 /*
 **  Standard poup menu
  */
 static PaintMenuItem popupMenu[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
 #define P_UNDO_ITEM	1
     MI_SIMPLE("undo"),
 #define P_REDO_ITEM	2
     MI_SIMPLE("redo"),
-    MI_SEPERATOR(),  /* 3 */
-#define P_CUT_ITEM	4
+    MI_SEPARATOR(),  /* 3 */
+#define P_REFRESH_ITEM	4
+    MI_SIMPLE("refresh"),
+    MI_SEPARATOR(),  /* 5 */
+#define P_CUT_ITEM	6
     MI_SIMPLE("cut"),
-#define P_COPY_ITEM	5
+#define P_COPY_ITEM	7
     MI_SIMPLE("copy"),
-#define P_PASTE_ITEM	6
+#define P_PASTE_ITEM	8
     MI_SIMPLE("paste"),
-#define P_CLEAR_ITEM	7
+#define P_CLEAR_ITEM	9
     MI_SIMPLE("clear"),
+    MI_SEPARATOR(),  /* 10 */
+#define P_SNAPSHOT_ITEM	11
+    MI_SIMPLE("snapshot")
 };
 
 void 
@@ -746,8 +790,10 @@ ccpAddStdPopup(Widget paint)
 
     ccpAddUndo(popupMenu[P_UNDO_ITEM].widget, paint);
     ccpAddRedo(popupMenu[P_REDO_ITEM].widget, paint);
+    ccpAddRefresh(popupMenu[P_REFRESH_ITEM].widget, paint);
     ccpAddCut(popupMenu[P_CUT_ITEM].widget, paint);
     ccpAddCopy(popupMenu[P_COPY_ITEM].widget, paint);
     ccpAddPaste(popupMenu[P_PASTE_ITEM].widget, paint);
     ccpAddClear(popupMenu[P_CLEAR_ITEM].widget, paint);
+    ccpAddSnapshot(popupMenu[P_SNAPSHOT_ITEM].widget, paint);
 }
