@@ -13,7 +13,7 @@
 /* |								       | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: fatBitsEdit.c,v 1.15 1996/10/25 13:20:32 torsten Exp $ */
+/* $Id: fatBitsEdit.c,v 1.17 1997/09/03 19:31:07 torsten Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/IntrinsicP.h>	/* for XtResizeWidget() */
@@ -208,7 +208,7 @@ FatCursorDraw(Widget w, FatCursorInfo * l, XMotionEvent * event)
     /* Snap to zoom grid */
     x = x / z * z;
     y = y / z * z;
-#ifndef TRUNC_SNAP
+#if 0
     if (event->x - x > z / 2)
 	x += z;
     if (event->y - y > z / 2)
@@ -660,6 +660,8 @@ FatbitsEdit(Widget paint)
     Position x, y, lx, ly;
     Dimension width = 48, height = 48;
     LocalInfo *l;
+    Arg args[3];
+    int nargs = 0;
     static char *zoomList[] =
     {
 	"zoomButton1",
@@ -690,9 +692,11 @@ FatbitsEdit(Widget paint)
     XtVaGetValues(paint, XtNcolormap, &cmap, XtNzoom, &l->zoom,
 		  XtNdownX, &lx, XtNdownY, &ly, NULL);
 
-    shell = XtVaCreatePopupShell("fatbits", topLevelShellWidgetClass,
-				 GetShell(paint), XtNcolormap, cmap,
-				 NULL);
+    XtSetArg(args[nargs], XtNcolormap, cmap); nargs++; 
+
+    shell = XtVisCreatePopupShell("fatbits", topLevelShellWidgetClass,
+				  GetShell(paint), args, nargs);
+
     l->shell = shell;
 
     PaletteAddUser(PaletteFind(shell, cmap), shell);
