@@ -13,7 +13,7 @@
 /* |								       | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: fileName.c,v 1.10 1998/02/24 20:38:43 torsten Exp $ */
+/* $Id: fileName.c,v 1.12 2000/10/02 20:55:17 torsten Exp $ */
 
 #include <X11/StringDefs.h>
 #include <X11/Intrinsic.h>
@@ -37,7 +37,7 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#if defined(SYSV) || defined(SVR4) || defined(__CYGWIN32__)
+#if defined(SYSV) || defined(SVR4) || defined(__CYGWIN__)
 #include <dirent.h>
 #else
 #include <sys/dir.h>
@@ -167,6 +167,26 @@ StdSaveRegionFile(Widget w, XtPointer paintArg, XtPointer junk)
 	Notice(paint, "No region selected presently");
 }
 
+void 
+StdCloneRegionFile(Widget w, XtPointer paintArg, XtPointer junk)
+{
+    Widget paint = (Widget) paintArg;
+    PaintWidget pw  = (PaintWidget) w;
+    Pixmap pix, mask;
+    Colormap cmap;
+    int width, height;
+
+    if (PwRegionGet(paint, &pix, &mask))
+      {
+          width = pw->paint.region.orig.width;
+          height = pw->paint.region.orig.height;
+          cmap = Global.region.cmap;
+
+          graphicCreate(makeGraphicShell(w), 
+                width, height, -1, pix, cmap);
+      }
+}
+
 void 
 StdSaveAsFile(Widget w, XtPointer paintArg, XtPointer junk)
 {
@@ -375,7 +395,7 @@ static void
 setCWD(arg_t * arg, char *dir)
 {
     DIR *dirp;
-#if defined(SYSV) || defined(SVR4) || defined(__alpha) || defined(__CYGWIN32__)
+#if defined(SYSV) || defined(SVR4) || defined(__alpha) || defined(__CYGWIN__)
     struct dirent *e;
 #else
     struct direct *e;
