@@ -13,7 +13,7 @@
 /* |                                                                   | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: fillOp.c,v 1.9 1996/04/19 07:58:52 torsten Exp $ */
+/* $Id: fillOp.c,v 1.11 1998/05/21 21:17:23 torsten Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -23,6 +23,9 @@
 #include <unistd.h>
 #include <math.h>
 #endif
+#ifdef __EMX__
+#include <float.h>
+#endif
 #include "Paint.h"
 #include "protocol.h"
 #include "xpaint.h"
@@ -445,6 +448,8 @@ press(Widget w, LocalInfo * l, XButtonEvent * event, OpInfo * info)
     if (fillMode != 1)
 	XDestroyImage(source);
 
+    XtFree((char *)mask);
+
     if (isBusy)
 	StateSetBusy(False);
 }
@@ -668,8 +673,11 @@ buildGradientPixmap(Widget w, OpInfo * info,
 		/* transform coords and take absolute value */
 		dx = x - ox;
 		dy = y - oy;
-		xx = abs(dx * cs - dy * sn);
-		yy = abs(dx * sn + dy * cs);
+ 		/* work-around for sco v5 cc internal compiler error */
+ 		xx = dx * cs - dy * sn;
+ 		if (xx < 0) xx = -xx;
+ 		yy = dx * sn + dy * cs;
+ 		if (yy < 0) yy = -yy;
 		if (xx < yy)
 		    s = yy;
 		else
