@@ -13,7 +13,7 @@
 /* |								       | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: graphic.c,v 1.22 1997/09/03 19:31:07 torsten Exp $ */
+/* $Id: graphic.c,v 1.26 2000/10/02 20:55:46 torsten Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
@@ -66,6 +66,9 @@
 
 #include "rw/rwTable.h"
 
+char *PRlabel, *PRcmd;
+char PRend[4];
+
 /* Global data */
 struct imageprocessinfo ImgProcessInfo =
 {
@@ -84,9 +87,6 @@ struct imageprocessinfo ImgProcessInfo =
     0, 0, 0, 0
 };
 
-#define PATTERN(name)	   \
-	(char *)CONCAT(name,_bits), CONCAT(name,_width), CONCAT(name,_height)
-
 struct paintWindows {
     Widget paint;
     struct paintWindows *next;
@@ -119,15 +119,19 @@ static PaintMenuItem fileMenu[] =
     MI_SIMPLE("save"),
 #define SAVEAS_ITEM 1
     MI_SIMPLE("saveas"),
-#define SAVER_ITEM 2
+#define SAVE_R_ITEM 2
     MI_SIMPLE("saveregion"),
-#define SAVE_CONFIG 3
+#define CLONE_R_ITEM 3
+    MI_SIMPLE("cloneregion"),
+#define SAVE_CONFIG 4
     MI_SIMPLE("saveconfig"),
-#define LOAD_CONFIG 4
+#define LOAD_CONFIG 5
     MI_SIMPLE("loadconfig"),
-#define REVERT_ITEM 5
+#define REVERT_ITEM 6
     MI_SIMPLE("revert"),
-#define CLOSE_ITEM 6
+#define PRINT_ITEM 7
+    MI_SIMPLE("print"),
+#define CLOSE_ITEM 8
     MI_SIMPLE("close"),
 };
 
@@ -137,19 +141,25 @@ static PaintMenuItem editMenu[] =
     MI_SIMPLE("undo"),
 #define REDO_ITEM	1
     MI_SIMPLE("redo"),
-    MI_SEPERATOR(),
-#define CUT_ITEM	3
+    MI_SEPARATOR(),
+#define REFRESH_ITEM	3
+    MI_SIMPLE("refresh"),
+    MI_SEPARATOR(),
+#define CUT_ITEM	5
     MI_SIMPLE("cut"),
-#define COPY_ITEM	4
+#define COPY_ITEM	6
     MI_SIMPLE("copy"),
-#define PASTE_ITEM	5
+#define PASTE_ITEM	7
     MI_SIMPLE("paste"),
-#define CLEAR_ITEM	6
+#define CLEAR_ITEM	8
     MI_SIMPLE("clear"),
-    MI_SEPERATOR(),
-#define DUP_ITEM	8
+    MI_SEPARATOR(),
+#define SNAPSHOT_ITEM	10
+    MI_SIMPLE("snapshot"),
+    MI_SEPARATOR(),
+#define DUP_ITEM	12
     MI_SIMPLE("dup"),
-#define SELECT_ALL_ITEM	9
+#define SELECT_ALL_ITEM	13
     MI_SIMPLE("all"),
 #if 0
     {"lock", NULL, NULL, MF_NONE, 0, NULL},
@@ -159,7 +169,7 @@ static PaintMenuItem editMenu[] =
 
 static PaintMenuItem rotateMenu[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_SIMPLE("rotate1"),
     MI_SIMPLE("rotate2"),
     MI_SIMPLE("rotate3"),
@@ -173,19 +183,19 @@ static PaintMenuItem regionMenu[] =
     MI_SIMPLE("flipX"),
 #define RG_FLIPY_ITEM	1
     MI_SIMPLE("flipY"),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
 #define RG_ROTATETO	3
     MI_RIGHT("rotateTo", XtNumber(rotateMenu), rotateMenu),
 #define RG_ROTATE	4
     MI_SIMPLE("rotate"),
-    MI_SEPERATOR(),		/* 5 */
+    MI_SEPARATOR(),		/* 5 */
 #define RG_CROP		6
     MI_SIMPLE("crop"),
-    MI_SEPERATOR(),		/* 7 */
+    MI_SEPARATOR(),		/* 7 */
 #ifdef FEATURE_TILT
 #define RG_TILT		8
     MI_SIMPLE("tilt"),
-    MI_SEPERATOR(),		/* 9 */
+    MI_SEPARATOR(),		/* 9 */
 #define RG_RESET	10
 #else
 #define RG_RESET	8
@@ -197,20 +207,20 @@ static PaintMenuItem filterMenu[] =
 {
 #define RG_LAST_ITEM	0
     MI_SIMPLE("last"),
-    MI_SEPERATOR(),		/* 1 */
+    MI_SEPARATOR(),		/* 1 */
 #define RG_INVERT_ITEM	2
     MI_SIMPLE("invert"),
 #define RG_SHARPEN_ITEM	3
     MI_SIMPLE("sharpen"),
   /* remove noise */
-    MI_SEPERATOR(),		/* 4 */
+    MI_SEPARATOR(),		/* 4 */
 #define RG_SMOOTH_ITEM	5
     MI_SIMPLE("smooth"),
 #define RG_DIRFILT_ITEM 6
     MI_SIMPLE("dirfilt"),
 #define RG_DESPECKLE_ITEM 7
     MI_SIMPLE("despeckle"),
-    MI_SEPERATOR(),		/* 8 */
+    MI_SEPARATOR(),		/* 8 */
 #define RG_EDGE_ITEM	9
     MI_SIMPLE("edge"),
 #define RG_EMBOSE_ITEM	10
@@ -229,7 +239,7 @@ static PaintMenuItem filterMenu[] =
 #define RG_SOLARIZE_ITEM 16
     MI_SIMPLE("solarize"),
   /* colour manipulation */
-    MI_SEPERATOR(),		/* 17 */
+    MI_SEPARATOR(),		/* 17 */
 #define RG_CONTRAST_ITEM 18
     MI_SIMPLE("contrast"),
 #define RG_QUANTIZE_ITEM 19
@@ -248,10 +258,10 @@ static PaintMenuItem otherMenu[] =
     MI_FLAG("snap", MF_CHECK),
 #define	CHSNAP_ITEM	3
     MI_SIMPLE("snapSpacing"),
-    MI_SEPERATOR(),		/* 4 */
+    MI_SEPARATOR(),		/* 4 */
 #define EDIT_BACKGROUND	5
     MI_SIMPLE("background"),
-    MI_SEPERATOR(),		/* 6 */
+    MI_SEPARATOR(),		/* 6 */
 #define	CHSIZE_ITEM	7
     MI_SIMPLE("size"),
 #define UNDOSZ_ITEM	8
@@ -279,10 +289,10 @@ static PaintMenuBar menuBar[] =
 
 static PaintMenuItem paletteMenu[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_SIMPLECB("edit", editPatternCB, NULL),
     MI_SIMPLECB("remove", deletePatternCB, NULL),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_SIMPLECB("help", HelpDialog, "canvas.patBox"),
 };
 
@@ -1218,6 +1228,49 @@ revertCallback(Widget w, XtPointer paintArg, XtPointer junk2)
 		 revertOkCallback, genericCancelCallback, paint);
 }
 
+static void
+printCallback(Widget w, XtPointer paintArg, XtPointer junk2)
+{
+    char *v, *file;
+    Widget paint = (Widget) paintArg;
+    Widget top;
+    Boolean flg;
+    char cmd[1024];
+
+    XtVaGetValues(paint, XtNfilename, &file, NULL);
+
+    if ((file == NULL) || (*file == 0)) {
+        AlertBox(GetShell(paint), "No file name!\nFirst save the image to a file",
+		 StdSaveAsFile, genericCancelCallback, paint);
+	return;
+    }
+
+    XtVaGetValues(paint, XtNdirty, &flg, NULL);
+
+    if (flg) {
+	AlertBox(GetShell(paint),
+		 "Unsaved changes!\nFirst save the modifications",
+		 StdSaveAsFile, genericCancelCallback, paint);
+        return;
+    }
+
+    top = GetToplevel(w);
+
+    StateSetBusy(True);
+
+    if ((v = ReadMagic(file)) == NULL) {
+	StateSetBusy(False);
+	Notice(top, "Unable to open input file \"%s\"\n	%s",
+	       file, RWGetMsg());
+	return;
+    }
+
+    sprintf(cmd, "%s %s %s", PRcmd, file, PRend);
+    system(cmd);
+
+    StateSetBusy(False);
+}
+
 /*
  * Pop up the fatbits window.
  */
@@ -2184,21 +2237,36 @@ graphicCreate(Widget shell, int width, int height, int zoom,
 
     ccpAddUndo(editMenu[UNDO_ITEM].widget, paint);
     ccpAddRedo(editMenu[REDO_ITEM].widget, paint);
+    ccpAddRefresh(editMenu[REFRESH_ITEM].widget, paint);
     ccpAddCut(editMenu[CUT_ITEM].widget, paint);
     ccpAddCopy(editMenu[COPY_ITEM].widget, paint);
     ccpAddPaste(editMenu[PASTE_ITEM].widget, paint);
     ccpAddClear(editMenu[CLEAR_ITEM].widget, paint);
     ccpAddDuplicate(editMenu[DUP_ITEM].widget, paint);
 
+    ADDCALLBACK(editMenu, SNAPSHOT_ITEM, paint, StdSnapshotCallback);
     ADDCALLBACK(editMenu, SELECT_ALL_ITEM, paint, StdSelectAllCallback);
     ADDCALLBACK(fileMenu, SAVEAS_ITEM, paint, StdSaveAsFile);
     ADDCALLBACK(fileMenu, SAVE_ITEM, paint, StdSaveFile);
 
-    ccpAddSaveRegion(fileMenu[SAVER_ITEM].widget, paint);
+    ccpAddSaveRegion(fileMenu[SAVE_R_ITEM].widget, paint);
+    ccpAddCloneRegion(fileMenu[CLONE_R_ITEM].widget, paint);
 
     ADDCALLBACK(fileMenu, REVERT_ITEM, paint, revertCallback);
     prCallback(paint, fileMenu[REVERT_ITEM].widget, False);
 
+    ADDCALLBACK(fileMenu, PRINT_ITEM, paint, printCallback);
+    XtVaGetValues(fileMenu[PRINT_ITEM].widget, XtNlabel, &PRlabel, NULL);
+    PRcmd = PRlabel;
+    while (*PRcmd != '|' && PRcmd<PRlabel+strlen(PRlabel)) ++PRcmd;
+    if (*PRcmd == '|') {
+      *PRcmd = '\0';
+      ++PRcmd;
+    i=strlen(PRcmd)-1;
+    while(i>=0 && isspace(PRcmd[i])) { PRcmd[i]='\0'; --i; }
+    if(PRcmd[i]=='&') { PRcmd[i]='\0'; strcpy(PRend, " &"); } else *PRend='\0';
+    }
+
     ADDCALLBACK(fileMenu, CLOSE_ITEM, paint, closeCallback);
     ADDCALLBACK(otherMenu, GRID_ITEM, paint, gridCallback);
     ADDCALLBACK(otherMenu, SNAP_ITEM, paint, snapCallback);
