@@ -13,7 +13,7 @@
 /* |                                                                   | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: operation.c,v 1.19 1998/03/23 21:39:51 torsten Exp $ */
+/* $Id: operation.c,v 1.21 2000/09/02 21:46:11 torsten Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -66,6 +66,7 @@
 #include "bitmaps/fovalOp.xpm"
 #include "bitmaps/lassoOp.xpm"
 #include "bitmaps/clineOp.xpm"
+#include "bitmaps/splineOp.xpm"
 #include "bitmaps/polyOp.xpm"
 #include "bitmaps/fpolyOp.xpm"
 #include "bitmaps/freehandOp.xpm"
@@ -474,6 +475,14 @@ loadClipboard(Widget w, XtPointer junk, XtPointer junk2)
     GetFileName(GetShell(w), 0, NULL, (XtCallbackProc) loadClipboardCB, NULL);
 }
 
+/*
+**
+ */
+static void 
+takeSnapshot(Widget w, XtPointer junk, XtPointer junk2)
+{
+    SnapshotImage(GetShell(w), junk, 0);
+}
 
 /*
 **  Button popups 
@@ -490,17 +499,18 @@ static void dynPencilPopupCB(Widget w, XtPointer junk, XtPointer junk2);
 static void selectShapePopupCB(Widget w, XtPointer junk, XtPointer junk2);
 static void sprayPopupCB(Widget w, XtPointer junk, XtPointer junk2);
 static void ovalPopupCB(Widget w, XtPointer junk, XtPointer junk2);
+static void splinePopupCB(Widget w, XtPointer junk, XtPointer junk2);
 static void boxPopupCB(Widget w, XtPointer junk, XtPointer junk2);
 
 #define GENERATE_HELP(name, hlpstr)				\
 		static PaintMenuItem name [] = {		\
-			MI_SEPERATOR(),				\
+			MI_SEPARATOR(),				\
 			MI_SIMPLECB("help", HelpDialog, hlpstr)	\
 		};
 
 static PaintMenuItem brushPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("opaque", MF_CHECKON | MF_GROUP1, brushPopupCB, 0),
     MI_FLAGCB("transparent", MF_CHECK | MF_GROUP1, brushPopupCB, 1),
     MI_SIMPLECB("select", BrushSelect, NULL),
@@ -509,7 +519,7 @@ static PaintMenuItem brushPopup[] =
 };
 static PaintMenuItem erasePopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("original", MF_CHECKON, erasePopupCB, 0),
     MI_SIMPLECB("select", changeBrushAction, NULL),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.erase"),
@@ -517,7 +527,7 @@ static PaintMenuItem erasePopup[] =
 
 static PaintMenuItem dynPencilPopup[] = 
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("autofinish", MF_CHECK, dynPencilPopupCB, 0),
     MI_SIMPLECB("select", changeDynPencilAction, NULL),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.dynpencil"),
@@ -525,7 +535,7 @@ static PaintMenuItem dynPencilPopup[] =
 
 static PaintMenuItem sprayPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("gauss", MF_CHECKON, sprayPopupCB, 0),
     MI_SIMPLECB("select", changeSprayAction, NULL),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.spray"),
@@ -533,7 +543,7 @@ static PaintMenuItem sprayPopup[] =
 
 static PaintMenuItem smearPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_SIMPLECB("select", BrushSelect, NULL),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.smear"),
 };
@@ -545,7 +555,7 @@ GENERATE_HELP(rayPopup, "toolbox.tools.ray")
 GENERATE_HELP(arcPopup, "toolbox.tools.arc")
 static PaintMenuItem fillPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("fill", MF_CHECKON | MF_GROUP1, fillPopupCB, 0),
     MI_FLAGCB("change", MF_CHECK | MF_GROUP1, fillPopupCB, 1),
     MI_FLAGCB("fill_range", MF_CHECK | MF_GROUP1, fillPopupCB, 2),
@@ -553,11 +563,11 @@ static PaintMenuItem fillPopup[] =
 };
 static PaintMenuItem tfillPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("fill", MF_CHECKON | MF_GROUP1, fillPopupCB, 0),
     MI_FLAGCB("change", MF_CHECK | MF_GROUP1, fillPopupCB, 1),
     MI_FLAGCB("fill_range", MF_CHECK | MF_GROUP1, fillPopupCB, 2),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("radial", MF_CHECKON | MF_GROUP2, tfillPopupCB2, TFILL_RADIAL),
     MI_FLAGCB("linear", MF_CHECK | MF_GROUP2, tfillPopupCB2, TFILL_LINEAR),
     MI_FLAGCB("conical", MF_CHECK | MF_GROUP2, tfillPopupCB2, TFILL_CONE),
@@ -568,11 +578,11 @@ static PaintMenuItem tfillPopup[] =
 #ifdef FEATURE_FRACTAL
 static PaintMenuItem ffillPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("fill", MF_CHECKON | MF_GROUP1, fillPopupCB, 0),
     MI_FLAGCB("change", MF_CHECK | MF_GROUP1, fillPopupCB, 1),
     MI_FLAGCB("fill_range", MF_CHECK | MF_GROUP1, fillPopupCB, 2),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("plasma", MF_CHECKON | MF_GROUP2, ffillPopupCB2, 0),
     MI_FLAGCB("clouds", MF_CHECK | MF_GROUP2, ffillPopupCB2, 1),
     MI_FLAGCB("landscape", MF_CHECK | MF_GROUP2, ffillPopupCB2, 2),
@@ -581,7 +591,7 @@ static PaintMenuItem ffillPopup[] =
 #endif
 static PaintMenuItem textPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_SIMPLECB("select", changeFontAction, NULL),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.text"),
 };
@@ -590,57 +600,65 @@ GENERATE_HELP(freehandPopup, "toolbox.tools.blob")
 GENERATE_HELP(clinePopup, "toolbox.tools.cline")
 static PaintMenuItem selectBPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("shape", MF_CHECKON | MF_GROUP1, selectPopupCB, 0),
     MI_FLAGCB("not_color", MF_CHECK | MF_GROUP1, selectPopupCB, 1),
     MI_FLAGCB("only_color", MF_CHECK | MF_GROUP1, selectPopupCB, 2),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("rectangle", MF_CHECKON | MF_GROUP2, selectShapePopupCB, 0),
     MI_FLAGCB("ellipse", MF_CHECK | MF_GROUP2, selectShapePopupCB, 1),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.select"),
 };
 static PaintMenuItem lassoPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("shape", MF_CHECKON | MF_GROUP1, selectPopupCB, 0),
     MI_FLAGCB("not_color", MF_CHECK | MF_GROUP1, selectPopupCB, 1),
     MI_FLAGCB("only_color", MF_CHECK | MF_GROUP1, selectPopupCB, 2),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.select"),
 };
 static PaintMenuItem selectAPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("shape", MF_CHECKON | MF_GROUP1, selectPopupCB, 0),
     MI_FLAGCB("not_color", MF_CHECK | MF_GROUP1, selectPopupCB, 1),
     MI_FLAGCB("only_color", MF_CHECK | MF_GROUP1, selectPopupCB, 2),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.select"),
 };
 static PaintMenuItem boxPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("center", MF_CHECK, boxPopupCB, 0),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.box"),
 };
 static PaintMenuItem fboxPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("center", MF_CHECK, boxPopupCB, 0),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.box"),
 };
 static PaintMenuItem ovalPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("center", MF_CHECK, ovalPopupCB, 0),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.oval"),
 };
 static PaintMenuItem fovalPopup[] =
 {
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_FLAGCB("center", MF_CHECK, ovalPopupCB, 0),
     MI_SIMPLECB("help", HelpDialog, "toolbox.tools.oval"),
 };
+static PaintMenuItem splinePopup[] =
+{
+    MI_SEPARATOR(),
+    MI_FLAGCB("open", MF_CHECKON | MF_GROUP1, splinePopupCB, 0),
+    MI_FLAGCB("closed", MF_CHECK | MF_GROUP1, splinePopupCB, 1),
+    MI_FLAGCB("closed_up", MF_CHECK | MF_GROUP1, splinePopupCB, 2),
+    MI_SIMPLECB("help", HelpDialog, "toolbox.tools.spline"),
+};
 
 static void 
 brushPopupCB(Widget w, XtPointer junk, XtPointer junk2)
@@ -660,6 +678,16 @@ ovalPopupCB(Widget w, XtPointer junk, XtPointer junk2)
     MenuCheckItem(ovalPopup[1].widget, m);
     MenuCheckItem(fovalPopup[1].widget, m);
 }
+
+static void 
+splinePopupCB(Widget w, XtPointer junk, XtPointer junk2)
+{
+    int nm = (int) junk;
+
+    SplineSetMode(nm);
+    MenuCheckItem(splinePopup[nm + 1].widget, True);
+}
+
 static void 
 boxPopupCB(Widget w, XtPointer junk, XtPointer junk2)
 {
@@ -779,6 +807,7 @@ GENERATE_OP(FFreehand)
 GENERATE_OP(CLine)
 GENERATE_OP(Fill)
 GENERATE_OP(TFill)
+GENERATE_OP(Spline)
 #ifdef FEATURE_FRACTAL
 GENERATE_OP(FFill)
 #endif
@@ -805,6 +834,8 @@ static IconListItem iconList[] =
      "<BtnDown>(2): changeBrush()", MENU(brush), None},
     {"erase", XPMMAP(erase), &EraseOp,
      "<BtnDown>(2): changeBrush()", MENU(erase), None},
+    {"spray", XPMMAP(spray), &SprayOp,
+     "<BtnDown>(2): changeSpray()", MENU(spray), None},
     {"pencil", XPMMAP(pencil), &PencilOp,
      NULL, MENU(pencil), None},
     {"dynpencil", XPMMAP(dynPen), &DynPencilOp, 	
@@ -817,8 +848,6 @@ static IconListItem iconList[] =
      NULL, MENU(lasso), None},
     {"selectPoly", XPMMAP(selpoly), &SelectPolyOp,
      NULL, MENU(selectA), None},
-    {"spray", XPMMAP(spray), &SprayOp,
-     "<BtnDown>(2): changeSpray()", MENU(spray), None},
     {"fill", XPMMAP(fill), &FillOp,
      NULL, MENU(fill), None},
     {"tfill", XPMMAP(tfill), &TFillOp,
@@ -829,32 +858,34 @@ static IconListItem iconList[] =
 #endif
     {"smear", XPMMAP(smear), &SmearOp,
      "<BtnDown>(2): changeBrush()", MENU(smear), None},
-    {"text", XPMMAP(text), &FontOp,
-     "<BtnDown>(2): changeFont()", MENU(text), None},
     {"line", XPMMAP(line), &LineOp,
      NULL, MENU(line), None},
     {"ray", XPMMAP(ray), &RayOp,
      NULL, MENU(ray), None},
-    {"arc", XPMMAP(arc), &ArcOp,
-     NULL, MENU(arc), None},
-    {"cLine", XPMMAP(cline), &CLineOp,
-     NULL, MENU(cline), None},
     {"box", XPMMAP(box), &BoxOp,
      NULL, MENU(box), None},
     {"fBox", XPMMAP(fbox), &FBoxOp,
      NULL, MENU(fbox), None},
+    {"text", XPMMAP(text), &FontOp,
+     "<BtnDown>(2): changeFont()", MENU(text), None},
     {"oval", XPMMAP(oval), &OvalOp,
      NULL, MENU(oval), None},
     {"fOval", XPMMAP(foval), &FOvalOp,
      NULL, MENU(foval), None},
+    {"arc", XPMMAP(arc), &ArcOp,
+     NULL, MENU(arc), None},
     {"polygon", XPMMAP(poly), &PolyOp,
      NULL, MENU(poly), None},
     {"fPolygon", XPMMAP(fpoly), &FPolyOp,
      NULL, MENU(poly), None},
+    {"cLine", XPMMAP(cline), &CLineOp,
+     NULL, MENU(cline), None},
     {"freehand", XPMMAP(freehand), &FreehandOp,
      NULL, MENU(freehand), None},
     {"fFreehand", XPMMAP(ffreehand), &FFreehandOp,
      NULL, MENU(freehand), None},
+    {"Spline", XPMMAP(spline), &SplineOp,
+     NULL, MENU(spline), None},
 };
 
 void 
@@ -913,7 +944,7 @@ static PaintMenuItem fontMenu[] =
 	      fontSet, "-*-fixed-medium-r-normal-*-*-120-*-*-m-*-*-*"),
     MI_FLAGCB("Courier 12", MF_CHECK | MF_GROUP1,
 	      fontSet, "-*-courier-medium-r-normal-*-*-120-*-*-m-*-*-*"),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
 #define FM_SELECT	11
     MI_FLAGCB("select", MF_CHECK | MF_GROUP1, fontSet, NULL),
 };
@@ -933,14 +964,15 @@ static PaintMenuItem fileMenu[] =
     MI_SIMPLECB("new-size", GraphicCreate, 2),
     MI_SIMPLECB("open", GraphicCreate, 1),
     MI_SIMPLECB("load-clip", loadClipboard, NULL),
-    MI_SEPERATOR(),
+    MI_SIMPLECB("snapshot", takeSnapshot, NULL),
+    MI_SEPARATOR(),
     MI_SIMPLECB("quit", exitPaint, NULL),
 };
 
 static PaintMenuItem helpMenu[] =
 {
     MI_SIMPLECB("about", HelpDialog, "about"),
-    MI_SEPERATOR(),
+    MI_SEPARATOR(),
     MI_SIMPLECB("help", HelpDialog, "toolbox.toolbox"),
 };
 
