@@ -10,7 +10,7 @@
 ** implied warranty.
  */
 
-/* $Id: libpnmrw.c,v 1.9 2000/10/02 20:53:00 torsten Exp $ */
+/* $Id: libpnmrw.c,v 1.10 2000/10/19 20:56:14 torsten Exp $ */
 
 #if defined(HAVE_PARAM_H)
 #include <sys/param.h>
@@ -139,7 +139,7 @@ pm_perror(char *reason)
 #ifdef __CYGWIN__
 #  define sys_errlist _sys_errlist
 #else
-   extern char *sys_errlist[]
+    extern char *sys_errlist[];
 #endif
 #endif
 #endif
